@@ -19,11 +19,12 @@
 
 from aliyunsdkcore.request import RpcRequest
 from aliyunsdkcbn.endpoint import endpoint_data
+import json
 
 class CreateTransitRouterRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Cbn', '2017-09-12', 'CreateTransitRouter','cbn')
+		RpcRequest.__init__(self, 'Cbn', '2017-09-12', 'CreateTransitRouter')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -51,6 +52,20 @@ class CreateTransitRouterRequest(RpcRequest):
 
 	def set_CenId(self, CenId):  # String
 		self.add_query_param('CenId', CenId)
+	def get_TransitRouterCidrList(self): # Array
+		return self.get_query_params().get('TransitRouterCidrList')
+
+	def set_TransitRouterCidrList(self, TransitRouterCidrList):  # Array
+		self.add_query_param("TransitRouterCidrList", json.dumps(TransitRouterCidrList))
+	def get_Tags(self): # RepeatList
+		return self.get_query_params().get('Tag')
+
+	def set_Tags(self, Tag):  # RepeatList
+		for depth1 in range(len(Tag)):
+			if Tag[depth1].get('Value') is not None:
+				self.add_query_param('Tag.' + str(depth1 + 1) + '.Value', Tag[depth1].get('Value'))
+			if Tag[depth1].get('Key') is not None:
+				self.add_query_param('Tag.' + str(depth1 + 1) + '.Key', Tag[depth1].get('Key'))
 	def get_DryRun(self): # Boolean
 		return self.get_query_params().get('DryRun')
 
