@@ -23,7 +23,7 @@ from aliyunsdkcbn.endpoint import endpoint_data
 class DescribeCenChildInstanceRouteEntriesRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Cbn', '2017-09-12', 'DescribeCenChildInstanceRouteEntries','cbn')
+		RpcRequest.__init__(self, 'Cbn', '2017-09-12', 'DescribeCenChildInstanceRouteEntries')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -81,6 +81,11 @@ class DescribeCenChildInstanceRouteEntriesRequest(RpcRequest):
 
 	def set_ChildInstanceId(self, ChildInstanceId):  # String
 		self.add_query_param('ChildInstanceId', ChildInstanceId)
+	def get_ChildInstanceRouteTableId(self): # String
+		return self.get_query_params().get('ChildInstanceRouteTableId')
+
+	def set_ChildInstanceRouteTableId(self, ChildInstanceRouteTableId):  # String
+		self.add_query_param('ChildInstanceRouteTableId', ChildInstanceRouteTableId)
 	def get_Status(self): # String
 		return self.get_query_params().get('Status')
 
