@@ -23,58 +23,51 @@ from aliyunsdkcbn.endpoint import endpoint_data
 class SetCenInterRegionBandwidthLimitRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Cbn', '2017-09-12', 'SetCenInterRegionBandwidthLimit','cbn')
+		RpcRequest.__init__(self, 'Cbn', '2017-09-12', 'SetCenInterRegionBandwidthLimit')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_CenId(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_CenId(self): # String
 		return self.get_query_params().get('CenId')
 
-	def set_CenId(self,CenId):
-		self.add_query_param('CenId',CenId)
-
-	def get_ResourceOwnerAccount(self):
+	def set_CenId(self, CenId):  # String
+		self.add_query_param('CenId', CenId)
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_OwnerAccount(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_OwnerAccount(self): # String
 		return self.get_query_params().get('OwnerAccount')
 
-	def set_OwnerAccount(self,OwnerAccount):
-		self.add_query_param('OwnerAccount',OwnerAccount)
-
-	def get_OppositeRegionId(self):
+	def set_OwnerAccount(self, OwnerAccount):  # String
+		self.add_query_param('OwnerAccount', OwnerAccount)
+	def get_OppositeRegionId(self): # String
 		return self.get_query_params().get('OppositeRegionId')
 
-	def set_OppositeRegionId(self,OppositeRegionId):
-		self.add_query_param('OppositeRegionId',OppositeRegionId)
-
-	def get_OwnerId(self):
+	def set_OppositeRegionId(self, OppositeRegionId):  # String
+		self.add_query_param('OppositeRegionId', OppositeRegionId)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_LocalRegionId(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_LocalRegionId(self): # String
 		return self.get_query_params().get('LocalRegionId')
 
-	def set_LocalRegionId(self,LocalRegionId):
-		self.add_query_param('LocalRegionId',LocalRegionId)
-
-	def get_BandwidthLimit(self):
+	def set_LocalRegionId(self, LocalRegionId):  # String
+		self.add_query_param('LocalRegionId', LocalRegionId)
+	def get_BandwidthLimit(self): # Long
 		return self.get_query_params().get('BandwidthLimit')
 
-	def set_BandwidthLimit(self,BandwidthLimit):
-		self.add_query_param('BandwidthLimit',BandwidthLimit)
\ No newline at end of file
+	def set_BandwidthLimit(self, BandwidthLimit):  # Long
+		self.add_query_param('BandwidthLimit', BandwidthLimit)
